<?php
require_once 'SebastianBergmann/CodeCoverage/autoload.php';
require_once __DIR__ . '/../tests/src/FileAnalyserTestCase.php';
require_once __DIR__ . '/../tests/src/TestCase.php';
require_once __DIR__ . '/../tests/_files/BankAccountTest.php';
